@@ -92,6 +92,7 @@ class Endpoint(BaseModel):
     type: Literal["mcp.sse", "meshagent.callable", "http", "tcp"]
     path: Optional[str | None] = None
     participant_name: Optional[str | None] = None
+    role: Optional[Literal["user", "tool", "agent"]] = None
 
 
 class Port(BaseModel):
@@ -116,7 +117,7 @@ class Service(BaseModel):
     runtime_secrets: Optional[Dict[str, str]] = None
     environment_secrets: Optional[list[str]] = None
     created_at: Optional[str] = None
-    ports: Optional[Dict[int, Port]] = (None,)
+    ports: Optional[Dict[str, Port]] = (None,)
     role: Optional[Literal["user", "tool", "agent"]] = None
     builtin: bool = Field(exclude=True, default=False)
 
