@@ -360,6 +360,9 @@ class Text(EventEmitter):
             ]
         )
 
+    def to_json(self, **extra):
+        return {"text": {"delta": self._data["delta"]}}
+
 
 def str_slice(s: str, start: int, end: int | None = None) -> str:
     if end is None:
@@ -457,18 +460,18 @@ class Document(EventEmitter):
         retain = 0
         if "elements" in message:
             for delta in message["elements"]:
-                if "retain" in delta:
+                if "retain" in delta and delta["retain"] is not None:
                     retain += delta["retain"]
 
-                if "insert" in delta:
+                if "insert" in delta and delta["insert"] is not None:
                     for insert in delta["insert"]:
-                        if "element" in insert:
+                        if "element" in insert and insert["element"] is not None:
                             node = self._createNode(target, insert)
                             splice(target._data["children"], retain, 0, node)
                             target.emit("inserted", node)
                             self.emit("inserted", node)
                             retain += 1
-                        elif "text" in insert:
+                        elif "text" in insert and insert["text"] is not None:
                             node = self._createNode(target, insert)
                             splice(target._data["children"], retain, 0, node)
                             target.emit("inserted", node)
@@ -477,7 +480,7 @@ class Document(EventEmitter):
                         else:
                             raise Exception("Unsupported element delta")
 
-                elif "delete" in delta:
+                elif "delete" in delta and delta["delete"] is not None:
                     removed = splice(target._data["children"], retain, delta["delete"])
                     for r in removed:
                         target.emit("deleted", r)
@@ -485,7 +488,11 @@ class Document(EventEmitter):
                     retain -= delta["delete"]
 
         # process text deltas
-        if "text" in message and len(message["text"]) != 0:
+        if (
+            "text" in message
+            and message["text"] is not None
+            and len(message["text"]) != 0
+        ):
             if target.tag_name != "text":
                 raise Exception("Node is not a text node: " + target.tag_name)
 
@@ -500,7 +507,7 @@ class Document(EventEmitter):
             targetDelta: list = textNode._data["delta"]
 
             for delta in message["text"]:
-                if "insert" in delta:
+                if "insert" in delta and delta["insert"] is not None:
                     if i == len(targetDelta):
                         attr = {}
                         if "attributes" in delta:
@@ -522,7 +529,7 @@ class Document(EventEmitter):
                         )
                         retain += len(delta["insert"])
 
-                elif "delete" in delta:
+                elif "delete" in delta and delta["delete"] is not None:
                     deleted = 0
                     while delta["delete"] > deleted:
                         remaining = delta["delete"] - deleted
@@ -556,7 +563,7 @@ class Document(EventEmitter):
                             end = str_slice(str_insert, remaining)
                             targetDelta[i]["insert"] = end
                             deleted += len(start)
-                elif "attributes" in delta:
+                elif "attributes" in delta and delta["attributes"] is not None:
                     formatted = 0
                     while delta["retain"] > formatted:
                         # format ends after item
@@ -666,6 +673,7 @@ class Document(EventEmitter):
 
         for change in message["attributes"]["set"]:
             target._data["attributes"][change["name"]] = change["value"]
+
             target.emit("updated", target, change["name"])
             self.emit("updated", target, change["name"])
 
